@@ -1,44 +1,30 @@
 package XML::Loy;
 use Mojo::ByteStream 'b';
-use Mojo::Loader qw/load_class/;
+use Mojo::Loader;
 use Carp qw/croak carp/;
-use Scalar::Util qw/blessed weaken/;
+use Scalar::Util 'blessed';
 use Mojo::Base 'Mojo::DOM';
 
-our $VERSION = '0.44_2';
-
-sub DESTROY;
-
 # Todo:
-#  - Add ->clone
-#    (Maybe via JSON serialisation of ->tree or using Storable or Dumper)
-#
 #   Maybe necessary: *AUTOLOAD = \&XML::Loy::AUTOLOAD;
 #
-# - sub try_further { };
-#     # usage:
-#     sub author {
-#       return $autor or $self->try_further;
-#     };
+#   sub try_further { };
+#   # usage:
+#   sub get_author {
+#     return $autor or $self->try_further;
+#   };
 #
-#  - ALERT!
-#      Do not allow for namespace islands
-#      Search $obj->find('* *[xmlns]') and change prefixing
-#      After ->SUPER::new;
-#      Or:
-#      Do allow for namespace islands and check for the
-#      namespace to add instead of the package name before
-#      prefixing.
+#  ALERT! Do not allow for namespace islands
+#         Search $obj->find('* *[xmlns]') and change prefixing
+#         After ->SUPER::new;
+#         Or:
+#         Do allow for namespace islands and check for the
+#         namespace to add instead of the package name before
+#         prefixing.
 #
-# - set() should really try to overwrite.
-#
-# - add() with -before => '' and -after => ''
-#   - maybe possible to save to element
-#   - Maybe with small changes a change to the object
-#     (encoding, xml etc.) can be done
-#
-# - closest() (jQuery)
+# Delete use of "constant"!
 
+our $VERSION = '0.04';
 
 our @CARP_NOT;
 
@@ -48,7 +34,10 @@ sub import {
 
   return unless my $flag = shift;
 
-  if ($flag =~ /^-?(?i:base|with)$/) {
+  if ($flag =~ /^-?(?i:with|base)$/) {
+
+    # Get class variables
+    my %param = @_;
 
     # Allow for manipulating the symbol table
     no strict 'refs';
@@ -58,22 +47,9 @@ sub import {
     my $caller = caller;
     push @{"${caller}::ISA"}, __PACKAGE__;
 
-    if (@_) {
-
-      # Get class variables
-      my %param = @_;
-
-      # Set class variables
-      foreach (qw/namespace prefix mime/) {
-	if (exists $param{$_}) {
-	  ${ "${caller}::" . uc $_ } = delete $param{$_};
-	};
-      };
-
-      # Set class hook
-      if (exists $param{on_init}) {
-	*{"${caller}::ON_INIT"} = delete $param{on_init};
-      };
+    # Set class variables
+    foreach (qw/namespace prefix mime/) {
+      ${ "${caller}::" . uc $_} = $param{$_} if exists $param{$_};
     };
   };
 
@@ -85,33 +61,19 @@ sub import {
 };
 
 
+use constant {
+  I  => '  ',
+  NS => 'http://sojolicio.us/ns/xml-serial',
+  PI => 'xml version="1.0" encoding="UTF-8" standalone="yes"'
+};
+
+
 # Return class variables
 {
   no strict 'refs';
-  sub _namespace { ${"${_[0]}::NAMESPACE"}   || '' };
-  sub _prefix    { ${"${_[0]}::PREFIX"}      || '' };
-  sub mime       {
-    ${ (blessed $_[0] || $_[0]) . '::MIME'}  || 'application/xml'
-  };
-  sub _on_init   {
-    my $class = shift;
-    my $self = $class;
-
-    # Run object method
-    if (blessed $class) {
-      $class = blessed $class;
-    }
-
-    # Run class method
-    else {
-      $self = shift;
-    };
-
-    # Run init hook
-    if ($class->can('ON_INIT')) {
-      *{"${class}::ON_INIT"}->($self) ;
-    };
-  };
+  sub _namespace { ${"${_[0]}::NAMESPACE"}  || '' };
+  sub _prefix    { ${"${_[0]}::PREFIX"}     || '' };
+  sub mime       { ${ref($_[0]) . '::MIME'} || 'application/xml' };
 };
 
 
@@ -119,22 +81,19 @@ sub import {
 sub new {
   my $class = shift;
 
-  my $self;
-
   # Create from parent class
-  # Empty constructor
-  unless ($_[0]) {
-    $self = $class->SUPER::new->xml(1);
+  unless ($_[0]) {                 # Empty constructor
+    return $class->SUPER::new;
   }
 
-  # XML::Loy object
-  elsif (ref $_[0]) {
-    $self = $class->SUPER::new(@_)->xml(1);
+  elsif (ref $_[0]) {              # XML::Loy object
+    return $class->SUPER::new(@_);
   }
 
-  # XML string
-  elsif (index($_[0],'<') >= 0 || index($_[0],' ') >= 0) {
-    $self = $class->SUPER::new->xml(1)->parse(@_);
+  elsif (index($_[0],'<') >= 0) {  # XML string
+    return $class->SUPER::new(@_);
+
+    # return _prefix_islands($obj);
   }
 
   # Create a new node
@@ -143,34 +102,34 @@ sub new {
     my $att  = ref( $_[0] ) eq 'HASH' ? shift : +{};
     my ($text, $comment) = @_;
 
-    $att->{'xmlns:loy'} = 'http://sojolicio.us/ns/xml-loy';
+    $att->{'xmlns:serial'} = NS;
 
     # Transform special attributes
     _special_attributes($att) if $att;
 
     # Create root
-    my $tree = [
-      'root',
-      [ pi => 'xml version="1.0" encoding="UTF-8" standalone="yes"']
-    ];
+    my $tree = ['root', [pi => PI]];
 
     # Add comment if given
-    push(@$tree, [ comment => $comment ]) if $comment;
+    push(@$tree, [comment => $comment]) if $comment;
 
     # Create Tag element
-    my $element = [ tag => $name, $att, $tree ];
+    my $element = ['tag', $name, $att, $tree];
 
     # Add element
     push(@$tree, $element);
 
     # Add text if given
-    push(@$element, [ text => $text ]) if defined $text;
+    push(@$element, [text => $text]) if $text;
 
     # Create root element by parent class
-    $self = $class->SUPER::new->xml(1);
+    my $root = $class->SUPER::new;
+
+    # Set object to xml strict
+    $root->xml(1);
 
     # Add newly created tree
-    $self->tree($tree);
+    $root->tree($tree);
 
     # The class is derived
     if ($class ne __PACKAGE__) {
@@ -179,15 +138,11 @@ sub new {
       if (my $ns = $class->_namespace) {
 	$att->{xmlns} = $ns;
       };
-
     };
+
+    # Return root node
+    return $root;
   };
-
-  # Start init hook
-  $self->_on_init;
-
-  # Return root node
-  return $self;
 };
 
 
@@ -199,15 +154,12 @@ sub add {
   my $tag = $_[0];
 
   # If node is root, use first element
-  if (!$self->parent &&
-	ref($self->tree->[1]) &&
-	  ref($self->tree->[1]) eq 'ARRAY' &&
-	    $self->tree->[1]->[0] eq 'pi') {
+  if (!$self->parent && $self->tree->[1]->[0] eq 'pi') {
     $self = $self->at('*');
   };
 
   # Add element
-  my $element = $self->_add_clean(@_) or return;
+  my $element = $self->_add_clean(@_);
 
   my $tree = $element->tree;
 
@@ -249,7 +201,7 @@ sub set {
 
   # Get tag from document object
   if (ref $_[0]) {
-    $tag = $_[0]->at('*')->tag;
+    $tag = $_[0]->at('*')->type;
   }
 
   # Get tag
@@ -281,18 +233,18 @@ sub set {
   my $att = $self->tree->[2];
 
   # Introduce attribute 'once'
-  $att->{'loy:once'} //= '';
+  $att->{'serial:once'} //= '';
 
   # Check if set to once
-  if (index($att->{'loy:once'}, "($tag)") >= 0) {
+  if (index($att->{'serial:once'}, "($tag)") >= 0) {
 
     # Todo: Maybe escaping - check in extensions
-    $self->children("$tag")->map('remove');
+    $self->children("$tag")->pluck('remove');
   }
 
   # Set if not already set
   else {
-    $att->{'loy:once'} .= "($tag)";
+    $att->{'serial:once'} .= "($tag)";
   };
 
   # Add a ref, not the tag
@@ -312,18 +264,11 @@ sub children {
   # It works as written in the documentation,
   # but is also aware of namespace prefixes.
 
-  # If node is root, use first element
-  if (!$self->parent &&
-	ref($self->tree->[1]) &&
-	  ref($self->tree->[1]) eq 'ARRAY' &&
-	    $self->tree->[1]->[0] eq 'pi') {
-    $self = $self->at('*');
-  };
-
   my @children;
+  my $charset = $self->charset;
   my $xml     = $self->xml;
   my $tree    = $self->tree;
-  my $type_l  = $type ? length $type : 0;
+  my $type_l  = length $type;
   for my $e (@$tree[($tree->[0] eq 'root' ? 1 : 4) .. $#$tree]) {
 
     # Make sure child is the right type
@@ -337,20 +282,17 @@ sub children {
 	next if $e->[1] ne $type;
       }
 
-      # Check, if type is valid, and ignore prefixes, cause tag is prefixed
-      elsif (index($e->[1], ':') > 0) {
-	next if substr($e->[1], (index($e->[1], ':') + 1)) ne $type;
-
+      # Check, if type is valid, but ignore prefixes
+      elsif (rindex($e->[1], $type) - (length($e->[1]) - $type_l)) {
+	next;
       };
     };
-
-    push(@children, $self->new->tree($e)->xml($xml));
+    push @children, $self->new->charset($charset)->tree($e)->xml($xml);
   }
 
   # Create new Mojo::Collection
-  return Mojo::Collection->new( @children );
-};
-
+  return Mojo::Collection->new(@children);
+}
 
 # Append a new child node to the XML Node
 sub _add_clean {
@@ -360,7 +302,7 @@ sub _add_clean {
   if (ref $_[0]) {
 
     # Serialize node
-    my $node = $self->SUPER::new->xml(1)->tree( shift->tree );
+    my $node = $self->SUPER::new( shift->to_xml );
 
     # Get root attributes
     my $root_attr = $node->_root_element->[2];
@@ -388,11 +330,11 @@ sub _add_clean {
     my $base_root_attr = $self->_root_element->[2];
 
     # Copy extensions
-    if (exists $root_attr->{'loy:ext'}) {
-      my $ext = $base_root_attr->{'loy:ext'};
+    if (exists $root_attr->{'serial:ext'}) {
+      my $ext = $base_root_attr->{'serial:ext'};
 
-      $base_root_attr->{'loy:ext'} =
-	join('; ', $ext, split(/;\s/, delete $root_attr->{'loy:ext'}));
+      $base_root_attr->{'serial:ext'} =
+	join('; ', $ext, split(/;\s/, $root_attr->{'serial:ext'}));
     };
 
 
@@ -412,10 +354,6 @@ sub _add_clean {
   # Node is a string
   else {
     my $name = shift;
-
-    # Pretty sloppy check for valid names
-    return unless $name =~ m!^-?[^\s<>]+$!;
-
     my $att  = shift if ref( $_[0] ) eq 'HASH';
     my ($text, $comment) = @_;
 
@@ -444,7 +382,7 @@ sub _add_clean {
       _special_attributes($att);
 
       # Add attributes to node
-      $node->attr($att);
+      $node->attrs($att);
     };
 
     # Add comment
@@ -462,7 +400,7 @@ sub _special_attributes {
   foreach ( grep { index($_, '-') == 0 } keys %$att ) {
 
     # Set special attribute
-    $att->{'loy:' . substr($_, 1) } = lc delete $att->{$_};
+    $att->{'serial:' . substr($_, 1) } = lc(delete $att->{$_});
   };
 };
 
@@ -508,34 +446,27 @@ sub extension {
   my $self = shift;
 
   # Get root element
-  my $root = $self->_root_element;
-
-  # No root to associate extension to
-  unless ($root) {
-    carp 'There is no document to associate the extension with';
-    return;
-  };
+  my $root = $self->_root_element or return;
 
   # Get ext string
-  my @ext = split(/;\s/, $root->[2]->{'loy:ext'} || '');
+  my @ext = split(/;\s/, $root->[2]->{'serial:ext'} || '');
 
   return @ext unless $_[0];
 
   # New Loader
-  # my $loader = Mojo::Loader->new;
+  my $loader = Mojo::Loader->new;
+
+  my $loaded = 0;
 
   # Try all given extension names
   while (my $ext = shift( @_ )) {
 
-    next if grep { $ext eq $_ } @ext;
+    next if $ext ~~ \@ext;
 
-    # Default 'XML::Loy::' prefix
-    if (index($ext, '-') == 0) {
-      $ext =~ s/^-/XML::Loy::/;
-    };
+    # Todo: Support default 'XML::Loy::' prefix
 
     # Unable to load extension
-    if (my $e = load_class $ext) {
+    if (my $e = $loader->load($ext)) {
       carp "Exception: $e"  if ref $e;
       carp qq{Unable to load extension "$ext"};
       next;
@@ -543,9 +474,7 @@ sub extension {
 
     # Add extension to extensions list
     push(@ext, $ext);
-
-    # Start init hook
-    $ext->_on_init($self);
+    $loaded++;
 
     if ((my $n_ns = $ext->_namespace) &&
 	  (my $n_pref = $ext->_prefix)) {
@@ -554,9 +483,9 @@ sub extension {
   };
 
   # Save extension list as attribute
-  $root->[2]->{'loy:ext'} = join('; ', @ext);
+  $root->[2]->{'serial:ext'} = join('; ', @ext);
 
-  return $self;
+  return $loaded;
 };
 
 
@@ -565,9 +494,7 @@ sub namespace {
   my $self = shift;
 
   # Get namespace
-  unless ($_[0]) {
-    return $self->SUPER::namespace || undef;
-  };
+  return $self->SUPER::namespace unless $_[0];
 
   my $ns = pop;
   my $prefix = shift;
@@ -584,59 +511,6 @@ sub namespace {
 };
 
 
-# As another object
-sub as {
-  my $self = shift;
-
-  # Base object
-  my $base = shift;
-
-  # New Loader
-  # my $loader = Mojo::Loader->new;
-
-  # Default 'XML::Loy::' prefix
-  if (index($base, '-') == 0) {
-    for ($base) {
-
-      # Was Loy prefix
-      s/^-Loy$/XML::Loy/;
-      s/^-/XML::Loy::/;
-    };
-  };
-
-  # Unable to load extension
-  if (my $e = load_class $base) {
-    carp "Exception: $e"  if ref $e;
-    carp qq{Unable to load base class "$e"};
-    return;
-  };
-
-  # Create new base document
-  my $xml = $base->new( $self->to_string );
-
-  # Start init hook
-  $xml->_on_init;
-
-  # Set base namespace
-  if ($base->_namespace) {
-    $xml->namespace( $base->_namespace );
-  };
-
-  # Delete extension information
-  $xml->find('*[loy\:ext]')->each(
-    sub {
-      delete $_->{attrs}->{'loy:ext'}
-    }
-  );
-
-  # Add extensions
-  $xml->extension( @_ );
-
-  # Return XML document
-  return $xml;
-};
-
-
 # Render as pretty xml
 sub to_pretty_xml {
   my $self = shift;
@@ -686,16 +560,16 @@ sub _render_pretty {
   elsif ($e eq 'comment') {
 
     # Padding for every line
-    my $p = '  ' x $i;
+    my $p = I x $i;
     my $comment = join "\n$p     ", split(/;\s+/, $tree->[1]);
 
-    return "\n" . ('  ' x $i) . "<!-- $comment -->\n";
+    return "\n" . (I x $i) . "<!-- $comment -->\n";
 
   }
 
   # Element is processing instruction
   elsif ($e eq 'pi') {
-    return ('  ' x $i) . '<?' . $tree->[1] . "?>\n";
+    return (I x $i) . '<?' . $tree->[1] . "?>\n";
 
   }
 
@@ -722,10 +596,10 @@ sub _element {
     unless $qname =~ /^(?:[a-zA-Z_]+:)?[^\s]+$/;
 
   # Start start tag
-  my $content = ('  ' x $i) . "<$qname";
+  my $content = (I x $i) . "<$qname";
 
   # Add attributes
-  $content .= _attr(('  ' x $i). (' ' x ( length($qname) + 2)), $attr);
+  $content .= _attr((I x $i). (' ' x ( length($qname) + 2)), $attr);
 
   # Has the element a child?
   if ($child->[0]) {
@@ -737,10 +611,10 @@ sub _element {
     if (!$child->[1] && ($child->[0] && $child->[0]->[0] eq 'text')) {
 
       # Special content treatment
-      if (exists $attr->{'loy:type'}) {
+      if (exists $attr->{'serial:type'}) {
 
 	# With base64 indentation
-	if ($attr->{'loy:type'} =~ /^armour(?::(\d+))?$/i) {
+	if ($attr->{'serial:type'} =~ /^armour(?::(\d+))?$/i) {
 	  my $n = $1 || 60;
 
 	  my $string = $child->[0]->[1];
@@ -749,9 +623,9 @@ sub _element {
 	  $string =~ tr{\t-\x0d }{}d;
 
 	  # Introduce newlines after n characters
-	  $content .= "\n" . ('  ' x ($i + 1));
-	  $content .= join  "\n" . ( '  ' x ($i + 1) ), (unpack "(A$n)*", $string );
-	  $content .= "\n" . ('  ' x $i);
+	  $content .= "\n" . (I x ($i + 1));
+	  $content .= join  "\n" . ( I x ($i + 1) ), (unpack "(A$n)*", $string );
+	  $content .= "\n" . (I x $i);
 	}
 
 	# No special treatment
@@ -771,10 +645,10 @@ sub _element {
     }
 
     # Treat children special
-    elsif (exists $attr->{'loy:type'}) {
+    elsif (exists $attr->{'serial:type'}) {
 
       # Raw
-      if ($attr->{'loy:type'} eq 'raw') {
+      if ($attr->{'serial:type'} eq 'raw') {
 
 	foreach (@$child) {
 
@@ -783,12 +657,12 @@ sub _element {
 	  $dom->xml(1);
 
 	  # Print without prettifying
-	  $content .= $dom->tree($_)->to_string;
+	  $content .= $dom->tree($_)->to_xml;
 	};
       }
 
       # Todo:
-      elsif ($attr->{'loy:type'} eq 'escape') {
+      elsif ($attr->{'serial:type'} eq 'escape') {
 	$content .= "\n";
 
 	foreach (@$child) {
@@ -805,7 +679,8 @@ sub _element {
 	};
 
 	# Correct Indent
-	$content .= '  ' x $i;
+	$content .= (I x $i);
+
       };
     }
 
@@ -815,7 +690,7 @@ sub _element {
       my $offset = 0;
 
       # First element is unformatted textual
-      if (!exists $attr->{'loy:type'} &&
+      if (!exists $attr->{'serial:type'} &&
 	    $child->[0] &&
 	      $child->[0]->[0] eq 'text') {
 
@@ -835,7 +710,7 @@ sub _element {
       };
 
       # Correct Indent
-      $content .= ('  ' x $i);
+      $content .= (I x $i);
     };
 
     # End Tag
@@ -859,7 +734,7 @@ sub _attr {
 
   # Delete special and namespace attributes
   my @special = grep {
-    $_ eq 'xmlns:loy' || index($_, 'loy:') == 0
+    $_ eq 'xmlns:serial' || index($_, 'serial:') == 0
   } keys %attr;
 
   # Delete special attributes
@@ -886,7 +761,7 @@ sub _root_element {
   # Todo: Optimize! Often called!
 
   # Find root (Based on Mojo::DOM::root)
-  my $root = $self->tree or return;
+  my $root = $self->tree;
   my $tag;
 
   # Root is root node
@@ -945,11 +820,8 @@ sub AUTOLOAD {
     };
   };
 
-  my $errstr = qq{Can't locate "${method}" in "$package"};
-  if (@ext) {
-    $errstr .= ' with extension' . (@ext > 1 ? 's' : '');
-    $errstr .= ' "' . join('", "', @ext) . '"';
-  };
+  my $errstr = qq{Can't locate "${method}()" in "$package"};
+  $errstr .= ' with ' . join(', ', @ext) . ' extensions' if @ext;
 
   carp $errstr and return;
 };
@@ -962,8 +834,6 @@ __END__
 
 =pod
 
-=encoding utf8
-
 =head1 NAME
 
 XML::Loy - Extensible XML Reader and Writer
@@ -973,7 +843,7 @@ XML::Loy - Extensible XML Reader and Writer
 
   use XML::Loy;
 
-  # Create new document with root node
+  # Create new dcument with root node
   my $xml = XML::Loy->new('env');
 
   # Add elements to the document
@@ -982,13 +852,13 @@ XML::Loy - Extensible XML Reader and Writer
   # Nest elements
   $header->add('greetings')->add(title => 'Hello!');
 
-  # Append elements with attributes and textual data
+  # Append elements with attributes
   $xml->add(body => { date => 'today' })->add(p => "That's all!");
 
   # Use CSS3 selectors for element traversal
-  $xml->at('title')->attr(style => 'color: red');
+  $xml->at('title')->attrs(style => 'color: red');
 
-  # Attach comments
+  # Attach comments to elements
   $xml->at('greetings')->comment('My Greeting');
 
   # Print with pretty indentation
@@ -1017,10 +887,12 @@ various namespaces.
 It focuses on simplicity and extensibility,
 while giving you the full power of L<Mojo::DOM>.
 
+B<This module is an early release! There may be significant changes in the future.>
+
 
 =head1 METHODS
 
-L<XML::Loy> inherits all explicit methods from
+L<XML::Loy> inherits all methods from
 L<Mojo::DOM> and implements the following new ones.
 
 
@@ -1037,7 +909,7 @@ L<Mojo::DOM> and implements the following new ones.
   $xml = XML::Loy->new(Document => { foo => 'bar' });
   my $xml_new = $xml->new(Document => {id => 'new'} => 'My Content');
 
-Constructs a new L<XML::Loy> document.
+Construct a new L<XML::Loy> document.
 Accepts either all parameters supported by L<Mojo::DOM> or
 all parameters supported by L<add|/add>.
 
@@ -1065,7 +937,7 @@ all parameters supported by L<add|/add>.
   $elem = $xml->new(Element => 'Hello World!');
   $xml->add($elem);
 
-Adds a new element to a L<XML::Loy> document, either
+Add a new element to a L<XML::Loy> document, either
 as another L<XML::Loy> object or newly defined.
 Returns the root node of the added L<XML::Loy>
 document.
@@ -1075,11 +947,10 @@ followed by an optional hash reference
 including all attributes of the XML element,
 an optional textual content,
 and an optional comment on the element
-(if the comment should be introduced to an empty element,
+(if the comment should be introduced without text content,
 text content has to be C<undef>).
 
-For giving directives for rendering element content
-with L<pretty printing|/to_pretty_xml>,
+For rendering element content with L<pretty printing|/to_pretty_xml>,
 a special C<-type> attribute can be defined:
 
 =over 2
@@ -1138,7 +1009,7 @@ Indent the content and automatically
 introduce linebreaks after every
 C<n>th character.
 Intended for base64 encoded data.
-Defaults to 60 characters line-width after indentation.
+Defaults to 60 characters linewidth after indentation.
 
   my $xml = XML::Loy->new('entry');
 
@@ -1179,83 +1050,36 @@ Defaults to 60 characters line-width after indentation.
   # Overwrite
   $xml->set(Element => { id => 6 });
 
-Adds a new element as a child to the node only once.
+Add a new element as a child to the node - only once.
 Accepts all parameters as defined in L<add|/add>.
 
 If one or more elements with the same tag name are
 already children of the requesting node,
-the old elements will be deleted and
-comments will be merged if possible.
+the old elements will be overwritten and
+comments will be merged.
 
 
 =head2 comment
 
   $node = $node->comment('Resource Descriptor');
 
-Prepends a comment to the current node.
+Prepend a comment to the current node.
 If a node already has a comment, comments will be merged.
 
 
 =head2 extension
 
-  # Add extensions
-  my $xml = $xml->extension('Fun', 'XML::Loy::Atom', -HostMeta);
-
-  # Further additions
-  $xml->extension(-Atom::Threading);
-
+  my $nr = $xml->extension('Fun', 'XML::Loy::Atom');
   my @extensions = $xml->extension;
 
-Adds or returns an array of extensions.
-When adding, returns the document.
+Add or get an array of extensions.
+When adding, returns the number of successfully added extensions.
 When getting, returns the array of associated extensions.
 
-The extensions are associated to the document, they are not associated
-to the object. That means, you can't add extensions to documents
-without a root node.
-
 With this package the following extensions are bundled:
-L<Atom|XML::Loy::Atom>,
-L<Atom-Threading|XML::Loy::Atom::Threading>,
-L<ActivityStreams|XML::Loy::ActivityStreams>,
-L<GeoRSS|XML::Loy::GeoRSS>,
-L<OStatus|XML::Loy::OStatus>,
-L<XRD|XML::Loy::XRD>,
-and L<HostMeta|XML::Loy::HostMeta>.
-If an extension has a leading minus symbol, it is assumed
-to be located in the C<XML::Loy> namespace, making C<XML::Loy::Atom>
-and C<-Atom> equivalent.
-
-See L<Extensions|/EXTENSIONS> for further information.
-
-B<Note:> The return value of the extension method is experimental
-and may change without warnings.
-
-
-=head2 as
-
-  my $xml = XML::Loy->new('<XRD><Subject>akron</Subject></XRD>');
-  my $xrd = $xml->as(-XRD, -HostMeta);
-
-  $xrd->alias('acct:akron@sojolicio.us');
-
-  print $xrd->to_pretty_xml;
-
-  # <XRD xmlns="http://docs.oasis-open.org/ns/xri/xrd-1.0"
-  #      xmlns:hm="http://host-meta.net/xrd/1.0"
-  #      xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
-  #   <Subject>akron</Subject>
-  #   <Alias>acct:akron@sojolicio.us</Alias>
-  # </XRD>
-
-Convert an L<XML::Loy> based object to another object.
-Accepts the base class and optionally a list of extensions.
-This only changes the namespace of the base class - extensions
-will stay intact.
-
-See L<Extensions|/EXTENSIONS> for further information.
-
-B<Note:> This method is experimental and may change without warnings!
+L<Atom|XML::Loy::Atom>, L<ActivityStreams|XML::Loy::ActivityStreams>,
+L<XRD|XML::Loy::XRD>, and L<HostMeta|XML::Loy::HostMeta>.
+See L<Extensions|/Extensions> for further information.
 
 
 =head2 mime
@@ -1263,7 +1087,7 @@ B<Note:> This method is experimental and may change without warnings!
   print $xml->mime;
 
 The mime type associated with the object class.
-See L<Extensions|/EXTENSIONS> for further information.
+See L<Extensions|/Extensions> for further information.
 
 
 =head2 namespace
@@ -1282,9 +1106,9 @@ See L<Extensions|/EXTENSIONS> for further information.
   #   <fun:test foo="bar">Works!</fun:test>
   # </doc>
 
-Returns the namespace of the node or
-adds namespace information to the node's root.
-When adding, the first parameter gives the prefix, the second one
+Get the namespace of the node or
+add namespace information to the node's root.
+On adding, the first parameter gives the prefix, the second one
 the namespace. The prefix parameter is optional.
 Namespaces are always added to the document's root,
 that means,
@@ -1298,16 +1122,16 @@ they have to be unique in the scope of the whole document.
 
 Returns a stringified, pretty printed XML document.
 Optionally accepts a numerical parameter,
-defining the start of indentation (defaults to C<0>).
+defining the start of indentation (defaults to 0).
 
 
 =head1 EXTENSIONS
 
   package Fun;
   use XML::Loy with => (
-    prefix    => 'fun',
+    prefix => 'fun',
     namespace => 'http://sojolicio.us/ns/fun',
-    mime      => 'application/fun+xml'
+    mime => 'application/fun+xml'
   );
 
   # Add new methods to the object
@@ -1323,16 +1147,11 @@ defining the start of indentation (defaults to C<0>).
 L<XML::Loy> allows for inheritance
 and thus provides two ways of extending the functionality:
 By using a derived class as a base class or by extending a
-base class with the L<extension|extension> method.
+base class with the L<extension|/extension> method.
 
 With this package the following extensions are bundled:
-L<Atom|XML::Loy::Atom>,
-L<Atom-Threading|XML::Loy::Atom::Threading>,
-L<ActivityStreams|XML::Loy::ActivityStreams>,
-L<GeoRSS|XML::Loy::GeoRSS>,
-L<OStatus|XML::Loy::OStatus>,
-L<XRD|XML::Loy::XRD>,
-and L<HostMeta|XML::Loy::HostMeta>.
+L<Atom|XML::Loy::Atom>, L<ActivityStreams|XML::Loy::ActivityStreams>,
+L<XRD|XML::Loy::XRD>, and L<HostMeta|XML::Loy::HostMeta>.
 
 For the purpose of extension, three attributes can be set when
 L<XML::Loy> is used (introduced with the keyword C<with>).
@@ -1397,13 +1216,13 @@ extension to another L<XML::Loy> based document as well.
 
 The defined namespace of C<Fun> is introduced with the
 prefix C<fun>. The prefix is prepended to all elements
-added by the L<add|/add> and L<set|/set> methods in the extension class.
+added by the L<add|/add> method in the extension class.
 To prevent this prefixing, prepend the element name with
 a C<-> (like with C<E<lt>-Cool /E<gt>> in the example
 above).
 
-Derived classes are always C<strict> and C<utf8>, use C<warnings>
-and import all C<features> of Perl 5.10.
+Derived classes are always strict and utf8, use warnings
+and import all features of Perl 5.10.
 
 
 =head1 DEPENDENCIES
@@ -1418,21 +1237,11 @@ serialized data and the ease of extensibility.
 It is - as well as the underlying parser - written in pure perl and
 not intended to be the fastest thing out there
 (although I believe there's plenty of space for optimization).
-That said - it may not suit all your needs, but there are loads of excellent
-XML libraries out there, you can give a try then.
-Just to name a few:
-For fast parsing of huge documents, try L<XML::Twig>.
+That said - it may not suits all your needs, but there are plenty of excellent
+other XML libraries out there, you should give a try then.
+Just to name a few: For fast parsing of huge documents, see L<XML::Twig>.
 For validation and the availability of lots of tools from the XML world,
-try L<XML::LibXML>.
-For simple deserialization,
-try L<XML::Bare> and L<XML::Fast>.
-For similar scope, but without dependencies aside the core,
-try L<XML::MyXML>.
-
-
-=head1 CONTRIBUTORS
-
-L<Renée Bäcker|https://github.com/reneeb>
+see L<XML::LibXML>.
 
 
 =head1 AVAILABILITY
@@ -1442,7 +1251,7 @@ L<Renée Bäcker|https://github.com/reneeb>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2013, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
