@@ -14,7 +14,7 @@ sub new {
 
 # host information
 sub host {
-  my $self = shift->root->at('*');
+  my $self = shift;
 
   unless ($_[0]) {
     my $h = $self->at('Host') or return;
@@ -35,7 +35,7 @@ __END__
 
 =head1 NAME
 
-XML::Loy::HostMeta - HostMeta Extension for XRD
+XML::Loy::Hostmeta - HostMeta Extension for XRD
 
 
 =head1 SYNOPSIS
@@ -43,7 +43,7 @@ XML::Loy::HostMeta - HostMeta Extension for XRD
   use XML::Loy::XRD;
 
   my $xrd = XML::Loy::XRD->new;
-  $xrd->extension(-HostMeta);
+  $xrd->extension('XML::Loy::HostMeta');
 
   $xrd->subject('http://sojolicio.us/');
   $xrd->host('sojolicio.us');
@@ -64,9 +64,11 @@ XML::Loy::HostMeta - HostMeta Extension for XRD
 L<XML::Loy::HostMeta> is an extension
 to L<XML::Loy::XRD> and provides addititional
 functionality for the work with
-L<HostMeta|https://tools.ietf.org/html/rfc6415>
+L<HostMeta|http://tools.ietf.org/html/draft-hammer-hostmeta>
 documents.
 
+B<This module is an early release! There may be significant changes in the future.>
+
 
 =head1 METHODS
 
@@ -79,9 +81,7 @@ from L<XML::Loy> and implements the following new ones.
   $xrd->host('sojolicio.us');
   print $xrd->host;
 
-Sets or returns host information of the xrd.
-The support of this element was removed from
-the specification in draft C<09>.
+Host information of the xrd.
 
 
 =head1 DEPENDENCIES
@@ -96,7 +96,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016, L<Nils Diewald|http://nils-diewald.de/>.
+Copyright (C) 2011-2013, L<Nils Diewald|http://nils-diewald.de/>.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
